@@ -47,15 +47,8 @@ using std::vector;
 namespace highlight
 {
 
-    LSPClient::LSPClient():
-    initialized(false),
-    hoverProvider(false),
-    semanticTokensProvider(false),
-    logRequests(false),
-    legacyProtocol(false),
-    initDelay(0),
-    msgId(1.0),
-    lastErrorCode(0)
+    LSPClient::LSPClient()
+    
     {
         serverName=serverVersion="?";
 
@@ -209,7 +202,7 @@ namespace highlight
             // Child
             dup2(outpipefd[0], STDIN_FILENO);
             dup2(inpipefd[1], STDOUT_FILENO);
-            dup2(inpipefd[1], STDERR_FILENO);
+            //dup2(inpipefd[1], STDERR_FILENO);
 
             #if __linux__
             //ask kernel to deliver SIGTERM in case the parent dies
@@ -225,7 +218,7 @@ namespace highlight
                 cmdArgs.push_back(const_cast<char*>(option.c_str()));
             }
 
-            cmdArgs.push_back(NULL);
+            cmdArgs.push_back(nullptr);
 
             // pass the vector's internal array to execvp
             char **command = cmdArgs.data();
@@ -288,17 +281,18 @@ namespace highlight
 
         std::string resultString;
 
-        resultString.resize(128);
+        const int initialRead = 128;
+        resultString.resize(initialRead);
         bool readOK = false;
 
         #ifdef _WIN32
 
         DWORD headerReadLen = 0;
-        readOK = ReadFile(g_hChildStd_OUT_Rd, (void*)resultString.data(), 128, &headerReadLen, NULL);
+        readOK = ReadFile(g_hChildStd_OUT_Rd, (void*)resultString.data(), initialRead, &headerReadLen, NULL);
 
         #else
 
-        ssize_t headerReadLen=read(inpipefd[0], (char*)resultString.data(), 128);
+        ssize_t headerReadLen=read(inpipefd[0], (char*)resultString.data(), initialRead);
         readOK = headerReadLen>0;
 
         #endif
@@ -395,7 +389,7 @@ namespace highlight
 
         picojson::array myTokenTypes;
         for (auto const &type : supportedTokenTypes)  {
-            myTokenTypes.push_back(picojson::value(type));
+            myTokenTypes.emplace_back(type);
         }
 
         vector<std::string> supportedModifiers {"documentation","declaration","definition","static","abstract","deprecated",
@@ -403,11 +397,11 @@ namespace highlight
 
         picojson::array myTokenModifiers;
         for (auto const &mod : supportedModifiers) {
-            myTokenModifiers.push_back(picojson::value(mod));
+            myTokenModifiers.emplace_back(mod);
         }
 
         picojson::array formats;
-        formats.push_back(picojson::value("relative"));
+        formats.emplace_back("relative");
 
         semanticTokensClientCapabilities["requests"] = picojson::value(requests);
 
@@ -424,7 +418,7 @@ namespace highlight
 
         //https://clangd.llvm.org/extensions.html#utf-8-offsets
         picojson::array offsetEncodings;
-        offsetEncodings.push_back(picojson::value("utf-8"));
+        offsetEncodings.emplace_back("utf-8");
         capabilities["offsetEncoding"] = picojson::value(offsetEncodings);
 
         params["capabilities"] = picojson::value(capabilities);
@@ -469,13 +463,13 @@ namespace highlight
         if (semanticTokensProvider) {
             picojson::array list = serverCapabilities.get("semanticTokensProvider").get("legend").get("tokenTypes").get<picojson::array>();
             int cnt=0;
-            for (picojson::array::iterator iter = list.begin(); iter != list.end(); ++iter) {
+            for (auto iter = list.begin(); iter != list.end(); ++iter) {
                 tokenTypes.insert( make_pair( cnt++, iter->get<std::string>()));
             }
 
             picojson::array modifiersList = serverCapabilities.get("semanticTokensProvider").get("legend").get("tokenModifiers").get<picojson::array>();
             cnt=0;
-            for (picojson::array::iterator iter = modifiersList.begin(); iter != modifiersList.end(); ++iter) {
+            for (auto iter = modifiersList.begin(); iter != modifiersList.end(); ++iter) {
                 tokenModifiers.insert( make_pair( cnt++, iter->get<std::string>()));
             }
         }
@@ -488,7 +482,7 @@ namespace highlight
         if (json.contains("method") && json.get("method").get<std::string>()=="textDocument/publishDiagnostics") {
             picojson::array diagnostics = json.get("params").get("diagnostics").get<picojson::array>();
 
-            for (picojson::array::iterator iter = diagnostics.begin(); iter != diagnostics.end(); ++iter) {
+            for (auto iter = diagnostics.begin(); iter != diagnostics.end(); ++iter) {
 
                 if ((int)iter->get("severity").get<double>() != 1){
                     continue;
@@ -546,6 +540,8 @@ namespace highlight
             return "";
         }
 
+        std::this_thread::sleep_for(std::chrono::milliseconds(initDelay));
+
         while (true) {
 
             std::string response = pipe_read_jsonrpc();
@@ -588,7 +584,7 @@ namespace highlight
             else if (jsonResponse.get("result").get("contents").is<picojson::array>()){
 
                 picojson::array list = jsonResponse.get("result").get("contents").get<picojson::array>();
-                for (picojson::array::iterator iter = list.begin(); iter != list.end(); ++iter) {
+                for (auto iter = list.begin(); iter != list.end(); ++iter) {
                     if ((*iter).is<std::string>()){
                         // pyls
                         hoverList.append( (*iter).get<std::string>());
@@ -672,7 +668,7 @@ namespace highlight
 
         vector<unsigned int> semAttributes;
         picojson::array list = jsonResponse.get("result").get("data").get<picojson::array>();
-        for (picojson::array::iterator iter = list.begin(); iter != list.end(); ++iter) {
+        for (auto iter = list.begin(); iter != list.end(); ++iter) {
             semAttributes.push_back((unsigned int)iter->get<double>());
         }
 
